#include "URLView.h"

#include <Application.h>
#include <Button.h>
#include <View.h>
#include <Window.h>



class Example : public BApplication {
	public:
								Example();
								~Example();
};



class ExampleWindow : public BWindow {
	public:
								ExampleWindow();
								~ExampleWindow();
								
		void					MessageReceived( BMessage *message );
		bool					QuitRequested();
		
		
	private:
		URLView					*web;
		URLView					*file;
		URLView					*email;
		URLView					*ftp;
};





int main( int argc, char **argv ) {
	new Example();
	be_app->Run();
	delete( be_app );
}



Example::Example()
	   : BApplication( "application/x-vnd.TallHill-URLView_Example_Application" ) {
	ExampleWindow *window = new ExampleWindow();
	window->Show();
}


Example::~Example() { }





ExampleWindow::ExampleWindow()
			 : BWindow( BRect( 150, 150, 490, 430 ), "URLView 2.11 Example Application", B_TITLED_WINDOW, 0 ) {
	
	BView *background = new BView( BRect( 0, 0, 340, 280 ), "Background", B_FOLLOW_LEFT_RIGHT, B_FOLLOW_TOP_BOTTOM );
	rgb_color gray = { 220, 220, 220 };
	background->SetViewColor( gray );
	AddChild( background );

	
	// Nifty title label.
	BStringView *title = new BStringView( BRect( 20, 20, 320, 50 ), "Title", "URLView 2.11 Link Examples" );
	title->SetFontSize( 24.0 );
	background->AddChild( title );

	
	// Labels explaining the various link types.
	BStringView *web_label = new BStringView( BRect( 20, 60, 150, 80 ), "Web Label", "Web link with big icon:" );
	background->AddChild( web_label );
	BStringView *file_label = new BStringView( BRect( 20, 100, 160, 120 ), "File Label", "File link with mini icon:" );
	background->AddChild( file_label );
	BStringView *email_label = new BStringView( BRect( 20, 140, 150, 160 ), "E-mail Label", "E-mail link with mini icon" );
	background->AddChild( email_label );
	BStringView *email_label2 = new BStringView( BRect( 20, 161, 150, 175 ), "E-mail Label2", "and hover turned off:" );
	background->AddChild( email_label2 );
	BStringView *ftp_label = new BStringView( BRect( 20, 200, 160, 220 ), "FTP Label", "FTP link with draggability",
		B_FOLLOW_LEFT | B_FOLLOW_BOTTOM, B_FULL_UPDATE_ON_RESIZE | B_WILL_DRAW );
	background->AddChild( ftp_label );
	BStringView *ftp_label2 = new BStringView( BRect( 20, 221, 160, 235 ), "FTP Label2", "disabled:",
		B_FOLLOW_LEFT | B_FOLLOW_BOTTOM, B_FULL_UPDATE_ON_RESIZE | B_WILL_DRAW );
	background->AddChild( ftp_label2 );
	
	BStringView *braggingText = new BStringView( BRect( 140, 260, 300, 280 ), "Bragging Label",
		"URLView was written by Billy Kakes", B_FOLLOW_RIGHT | B_FOLLOW_BOTTOM );
	braggingText->SetHighColor( 140, 140, 140 );
	braggingText->ResizeToPreferred();
	background->AddChild( braggingText );
	
	
	
	// We'll add the URLViews with the default colors.
	// This is a link for a web URL.
	web = new URLView( BRect( 175, 60, 320, 80 ), "Web", "Tall Hill Software", "http://www.tallhill.com" );
	web->SetIconSize( B_LARGE_ICON );
	web->SetFontSize( 18.0 );
	web->AddAttribute( "META:keyw", "Tall Hill Software" );
	web->SetUnderlineThickness( 2 );
	background->AddChild( web );
	
	// This is a link for a file URL.175, 97, 320, 117
	file = new URLView( BRect( 175, 100, 320, 120 ), "File", "The Be Book", "file:///boot/beos/documentation/Be%20Book/index.html" );
	background->AddChild( file );
	
	// This is a link for an e-mail address.
	email = new URLView( BRect( 175, 152, 320, 172 ), "E-mail", "Billy Kakes", "bkakes@tallhill.com" );
	email->SetHoverEnabled( false );
	email->AddAttribute( "META:name", "Billy Kakes" );
	email->AddAttribute( "META:nickname", "bkakes" );
	email->AddAttribute( "META:company", "Tall Hill Software" );
	email->AddAttribute( "META:url", "http://www.tallhill.com" );
	email->AddAttribute( "META:state", "CA" );
	email->AddAttribute( "META:country", "United States" );
	background->AddChild( email );
	
	// This is a link for an FTP server.
	ftp = new URLView( BRect( 175, 210, 320, 230 ), "FTP", "Be's FTP server", "ftp://ftp.be.com",
		B_FOLLOW_ALL_SIDES, B_WILL_DRAW | B_FULL_UPDATE_ON_RESIZE );
	ftp->SetDraggable( false );
	background->AddChild( ftp );
	
	
	// This is a button to toggle making the links enabled.
	BButton *button = new BButton( BRect( 20, 250, 120, 270 ), "Toggle Button",
								   "Toggle Links", new BMessage( 'BUTP' ), B_FOLLOW_LEFT | B_FOLLOW_BOTTOM );
	button->ResizeToPreferred();
	background->AddChild( button );
}
			 

ExampleWindow::~ExampleWindow() { }



void ExampleWindow::MessageReceived( BMessage *message ) {
	if( message->what == 'BUTP' ) {
		if( web->IsEnabled() ) {
			web->SetEnabled( false );
			file->SetEnabled( false );
			email->SetEnabled( false );
			ftp->SetEnabled( false );
		}
		else {
			web->SetEnabled( true );
			file->SetEnabled( true );
			email->SetEnabled( true );
			ftp->SetEnabled( true );
		}
	}
}



bool ExampleWindow::QuitRequested() {
	be_app->PostMessage( B_QUIT_REQUESTED );
	return true;
}
